#
# spec file for package python-bsddb3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-bsddb3
Version:        6.2.9
Release:        4.1
Summary:        Python interface for Berkeley DB
License:        BSD-3-Clause
URL:            http://pypi.python.org/pypi/bsddb3
#Freecode-URL:	 https://www.jcea.es/programacion/pybsddb.htm
Source:         https://files.pythonhosted.org/packages/source/b/bsddb3/bsddb3-%{version}.tar.gz
Patch0:         support-python312.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  db-devel
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-testsuite
%python_subpackages

%description
This module provides a nearly complete wrapping of the Oracle/Sleepycat C API
for the Database Environment, Database, Cursor, Log Cursor, Sequence and
Transaction objects, and each of these is exposed as a Python type in the
bsddb3.db module.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}

%description devel
This module provides a nearly complete wrapping of the Oracle/Sleepycat C API
for the Database Environment, Database, Cursor, Log Cursor, Sequence and
Transaction objects, and each of these is exposed as a Python type in the
bsddb3.db module.

This package contains the development files for %{name}

%prep
%autosetup -p1 -n bsddb3-%{version}
sed -i "1d" Lib/bsddb/dbshelve.py # Fix non-executable bits

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_expand rm -rf %{buildroot}%{$python_sitearch}/bsddb3/tests

%check
%python_exec test.py

%files %{python_files}
%doc ChangeLog README.txt TODO.txt docs/*
%license licenses.txt LICENSE.txt
%{python_sitearch}/bsddb3
%{python_sitearch}/bsddb3-%{version}.dist-info

%files %{python_files devel}
%license licenses.txt LICENSE.txt
%{_includedir}/python%{python_version}*/bsddb3

%changelog
* Sat Apr  6 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Feb  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python312.patch:
  * Fix the test script to support Python 3.12.
- Use fdupes.
- Switch to autosetup macro.
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- switch to pep517 build
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 6.2.9:
  * For some reason, 6.2.8 release was incomplete. Let's try again.
  * In Python 3.9, "find_unused_port" has been moved to
    "test.support.socket_helper". Reported by Michał Górny.
  * If we use "set_get_returns_none()" in the environment,
    the value could not be correctly inherited by the child
    databases. Reported by Patrick Laimbock and modern GCC
    warnings.
  * If you install this library under Python 3 >= 3.6, let
    you know this is a legacy library and urges you to
    migrate to "berkeleydb" library.
  * Update copyright notices.
  * https links.
  * Fix Python 3 deprecation warning.
    Notified by Arthur Gautier.
  * Fix compilation Python 3.8 deprecation warnings.
  * Fix compilation Python 3.9 deprecation warnings.
* Mon Jul 23 2018 tchvatal@suse.com
- Version Update to 6.2.6:
  * Correctly detect berkley db
  * Python 3.7 tested and explicitly supported
* Thu May 10 2018 toddrme2178@gmail.com
- Update to 6.2.5
  * We should be able to install inside a PYPY virtualenv.
    Reported by Zhihao Yuan.
- Use license tag
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to 6.2.4:
  * More complete fix for pkgsrc.
- Update to 6.2.3:
  * Update copyright notices.
  * Solve a conflict between different installations of Berkeley DB
    on some pkgsrc configurations.
- Update to 6.2.2:
  * Correctly detect Berkeley DB installations in SmartOS native zones.
  * "Probably" (not tested) correctly detect Berkeley DB in pkgsrc systems.
- Update to 6.2.1:
  * Correctly detect Berkeley DB installations in modern 64 bits Debians.
- Update to 6.2.0:
  * Support Berkeley DB 6.2.x.
  * Declare Python 3.5 support for PyPI.
  * Drop support for Python 3.2. If you need
    compatibility with that version, you can keep using
    old releases of these bindings.
  * Drop support for Berkeley DB 5.0, 5.2 and 6.0. If you need
    compatibility with those versions, you can keep using old
    releases of these bindings.
- Update to 6.1.1:
  * Compatibility with Python 3.5.
  * Code cleanup after dropping Python 2.4/2.5 support.
  * PGP key changed.
  * Support for DB_FORCESYNCENV flag in "DB_ENV.close()".
  * Support for DB_LOG_NOSYNC flag in "DB_ENV.log_set_config()".
  * Fix tests under Windows. See https://bugs.python.org/issue22943 .
  * Solve an incorrect parameter verification with the
    "DB.compact()" method call.
  * Solve a compilation warning when compiling the bindings for
    Python 3.5 and Berkeley DB 4.8, 5.0 or 5.1.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Jul 28 2014 mlin@suse.com
- Packaged licenses.txt LICENSE.txt README.txt
* Fri Jul 25 2014 mlin@suse.com
- Update to 6.1.0. Changes from 6.0.0
  * Support Berkeley DB 6.1.x.
  * Solve a ResourceWarning when compiling.
  * Drop support for Python 2.4, 2.5 and 3.1. If you need compatibility
    with those versions, you can keep using old releases of these bindings.
  * Drop support for Berkeley DB 4.3, 4.4, 4.5, 4.6. If you need compatibility
    with those versions, you can keep using old releases of these bindings.
  * From now, on our support reference is Red Had Enterprise Linux 6.
  * Drop modules attributes "cvsid".
  * Drop (hidden) $Id$ keyword in the documentation.
  * Clarification of license. This work is now explicitly licensed under 3-clause BSD license.
  * Fixed a long standing bug (August 2008, rev 9fd52748fa59) on "dbtables.py".
  * If you want to link with Oracle Berkeley DB 6.0, you will need to create the
    environment variable 'YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION' to
    signal to the pybsddb that you are legal. To be legal, your code MUST be
    AGPL3 *OR* you have to buy a commercial license from Oracle.
- Change license to BSD-3-Clause according to upstream changes
- Removed python-bsddb3.keyring and .asc file
* Sat Jun 22 2013 jengelh@inai.de
- Update to new upstream release 6.0.0
  * Support for BDB 6.0.19
  * HEADS UP: If you are using "bsddb3._bsddb" in your code, for
  example for exceptions, change it to "bsddb3._db".
- Removed bsddb3-db6.diff (rendered obsolete)
* Sat Jun 15 2013 jengelh@inai.de
- Add bsddb3-db6.diff to make setup[23].py look for BDB 6.0
- Signature verification
* Wed Jan 16 2013 mlin@suse.com
- Removed BuildArch: noarch macro
* Mon Jan 14 2013 saschpe@suse.de
- Simplify macro usage
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Jan 11 2013 mlin@suse.com
- Update to version 5.3.0
  * Support Berkeley DB 5.3.x.
  * Drop support for Berkeley DB 4.2 and Python 2.3. Our reference
    is Red Had Enterprise Linux 5, until march 2014. After that,
    RHEL6 has Python 2.6 and BDB 4.7.
  * According to
    http://superuser.com/questions/189931/python-and-berkeley-db-versions-in-redhat-enterprise-linux-3-4-5-and-upcoming-6:
  * RHEL3: Python 2.2.3, BDB 4.1.25
  * RHEL4: Python 2.3.4, BDB 4.2.52
  * RHEL5: Python 2.4.3, BDB 4.3.29
  * RHEL6: Python 2.6.2, BDB 4.7.25
  * Support for "DBEnv->set_intermediate_dir()", available in
    Berkeley DB 4.3-4.6.  Patch by Garret Cooper.
  * Support for "DB->set_dup_compare()".  Original patches by
    Nikita M. Kozlovsky and Ben Schmeckpeper.
  * Fixed a testsuite compatibility problem with BDB 5.2.
  * If we are running Solaris or derivatives, and 64bit python,
    try to find the library under "/usr/local/Berkeley.*.*/64/".
  * Solaris 10 Update 10 exposes a very old race condition in the
    replication master election tests. Some details in
    https://forums.oracle.com/forums/thread.jspa?messageID=9902860 .
    Workaround proposed in a private email from Paula Bingham (Oracle),
    in 20110929.
  * When doing the full matrix test for a release, stop the verification
    if any test failed.
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 5.2.0:
  * Support for Berkeley DB 5.2.
  * Support for the newly available replication manager events:
    DB_EVENT_REP_SITE_ADDED, DB_EVENT_REP_SITE_REMOVED,
    DB_EVENT_REP_LOCAL_SITE_REMOVED, DB_EVENT_REP_CONNECT_BROKEN,
    DB_EVENT_REP_CONNECT_ESTD, DB_EVENT_REP_CONNECT_TRY_FAILED,
    DB_EVENT_REP_INIT_DONE.
  * New Object: "DB_SITE". Support for all its methods.
  * Parameters for "DB_SITE->set_config()": DB_BOOTSTRAP_HELPER,
    DB_GROUP_CREATOR, DB_LEGACY, DB_LOCAL_SITE, DB_REPMGR_PEER.
  * Support for some stuff in the new "Dynamic Environment Configuration":
    DB_MEM_LOCK, DB_MEM_LOCKOBJECT, DB_MEM_LOCKER, DB_MEM_LOGID,
    DB_MEM_TRANSACTION, DB_MEM_THREAD.
  * Add "bytes" to "DBEnv_memp_stat()". Original patch from Garrett Cooper.
- Spec file cleanup:
  * Split of devel package for headers
  * Don't package tests
  * Fix non-executable bits
* Thu Nov 18 2010 hvogel@novell.com
  * Testsuite for "DB->get_transactional()" should not create databases
  outside the TMP directory, neither leave the files behind.
  * If something happens while creating the CObject/Capsule object,
  keep going, even without exporting the C API, instead of crashing.
  * Support for:
  * "DB_FORCESYNC", "DB_FAILCHK", "DB_SET_REG_TIMEOUT",
  * "DB_TXN_BULK", "DB_HOTBACKUP_IN_PROGRESS".
  * "DB_EVENT_REG_ALIVE", "DB_EVENT_REG_PANIC",
  * "DB_EVENT_REP_DUPMASTER", "DB_REPMGR_CONF_ELECTIONS",
  * "DB_EVENT_REP_ELECTION_FAILED", "DB_EVENT_REP_MASTER_FAILURE".
  * "DB_VERB_REP_ELECT", "DB_VERB_REP_LEASE", "DB_VERB_REP_MISC",
  * "DB_VERB_REP_MSGS", "DB_VERB_REP_SYNC", "DB_VERB_REP_SYSTEM",
  * "DB_VERB_REPMGR_CONNFAIL", "DB_VERB_REPMGR_MISC".
  * "DB_STAT_LOCK_CONF", "DB_STAT_LOCK_LOCKERS",
  * "DB_STAT_LOCK_OBJECTS", "DB_STAT_LOCK_PARAMS".
  * "DB_REP_CONF_INMEM", "DB_TIMEOUT ", "DB_CURSOR_BULK".
  * "DB->get_transactional()", "DB_REPMGR_ACKS_ALL_AVAILABLE"
  * Support for Berkeley DB 5.1.
  * Drop support for Berkeley DB 4.1
  * Include processed HTML documentation in the EGG.
  * Some link fixes for external documentation.
  * Links added in the documentation to Oracle Berkeley DB programmer
  reference.
* Wed Nov 10 2010 coolo@novell.com
- fix file list
* Wed Sep 29 2010 rhafer@novell.com
- Use generic db-devel in BuildRequires instead of libdb-4_5-devel.
* Tue Jun 22 2010 hvogel@novell.com
- Initial Package, Version 5.0.0
